# 🤺 Enguard

One guardrail for all, all guardrails for one!

## Installation

```bash
pip install enguard
```

## Quick Start

## Guard Types

Guard types are focused on the type of guardrail you want to apply to your model.

- `input_guardrail`: Guardrail for the input of the model.
- `output_guardrail`: Guardrail for the output of the model.
- `both_guardrail`: Guardrail for both the input and output of the model.

## Guardrail Types

Guardrail types are focused on the type of guardrail you want to apply to your model.

- `input_guardrail`: Guardrail for the input of the model.